//--------------------------------------------------------- AnticipationTest
// This code produces the content of Table 6 (Article) and Table A9 (Online Appendix),
// that is, it implements a test of anticipation a' la Grogger and Michalopoulus (JPE 2003).
// Note: Limitations of the GM test applied to MDRC's Public Use Files is that
// this test is differently from GM because we cannot stop using monthly observations when
// youngest kid turns 18 since we do not know when that happens.
// 
// This code is embedded into a program to make the output (written to STATA Results' window) more readable.
//
// This code has four parts:
// 	PART 1: sets parameters/ preferences which determine which Table to reproduce, which part of the code to run etc.
// 	PART 2: works on the data in entry to prepare it for PART 3
// 	PART 3: computes all the entries of the Table to reproduce
//	PART 4: send code for execution 
//
// This code take as inputs:
// 	1. pre-generated MDRC data
// 
// This code outputs:
// 	1. .log file with the output appearing on STATA's Results window.
// 
// Last Revision: 08/15/2015
//-------------------------------------------------------------------------------------------------------------------------------
args jf_dtain 







capture program drop AnticipationTest
capture program define AnticipationTest
args jf_dtain
	//------------------------------------------------ PART 1  ------------------------------------------------------
	// Pick what you want to do by setting a few local variables.
	//---------------------------------------------------------------------------------------------------------------
	//-----------------------------------------------------------------------
	// Pick:
	//	- the first (fm) and last (lm) month used in analysis
	//	- the age range [fa,la] such that if the unit's youngest kid's age belong 
	//    to that range time limits should not impact welfare participation
	//	- the age range [fb,lb] such that if the unit's youngest kid's age belong
	//    to that range time limits may impact welfare participation
	//-----------------------------------------------------------------------
	local fm = 1  
	local lm = 21 
	local fa = 16 
	local la = 17 
	local fb = 0 // either 0 or 14      
	local lb = `fa'-1 
	
	//-----------------------------------------------------------------------
	// Use the choices made above to:
	// - Define the observations to retain,
	// - Assign informative names to the files produced below.
	//
	// Note: by asking yngchtru to fall within a finite range, we are automatically excluding
	//       all cases with kidcount==. b/c kdicount==. => yngchtru==.
	//-----------------------------------------------------------------------
	local mysample "month>=`fm'&month<=`lm'&yngchtru>=`fb'&yngchtru<=`la'" 	
	//----------------------------------------------------------------------- 
	if `fb'==0 {
		local whatwedo 	"Table6"	
	}
	else if `fb'==14 {
		local whatwedo 	"TableA9"	
	}
	else {
		di "Your choice of options is not reproducing any of the Tables in the article or the Appendix."
		STOP
	}
	local logfileout	"$oJF/`whatwedo'.log"		// for keeping track

	
	
	
	
	
	
	//------------------------------------------------ PART 2  ------------------------------------------------------
	// Prepare the data for running the anticipation test
	//---------------------------------------------------------------------------------------------------------------	
	//------------------------------------------------
	// Save a temporary file containing welfare 
	// assistance status information, reshaped wide
	//------------------------------------------------
	tempfile tempf
	qui use "`jf_dtain'" if `mysample', clear
	keep id afdcon month
	qui reshape wide afdcon, i(id) j(month)
	sort id
	qui save `tempf', replace
	//------------------------------------------------
	qui use "`jf_dtain'" if `mysample'&quarter==1, clear
	keep yngchtru e month quarter id pufid $pscorevars
	// ---------------------------------------------------	
	// Get rid of the long dimension of the data; stay with wide-format.
	// ---------------------------------------------------	
	qui gen nm = .
	qui bys id quarter: replace nm = _n
	qui keep if nm==1 //wlog
	drop nm
	//------------------------------------------------
	// Bring in information on being on welfare assistance
	//------------------------------------------------
	qui merge 1:1 id using `tempf'
	assert _m==3
	drop _m
	//---------------------------------------------------
	keep yngchtru afdcon* id e $pscorevars
	qui reshape long afdcon@, i(id) j(m) 	
	assert yngchtru!=. // no worries about missing the age of the youngest kid
	//---------------------------------------------------
	// Generate indicator variables for the cross-product
	// of the treatment indicator and the age range indicator.
	// e.g. 
	// eT0 =1 if JF-treatment & age group with possibility of anticipation under JF, 0 otherwise
	// eT1 =1 if JF-treatment & age group with no anticipation under JF b/c too old, 0 otherwise
	// eC0 =1 if AFDC-treatment & age group with possibility of anticipation under JF, 0 otherwise
	//---------------------------------------------------
	qui gen g = (yngchtru>=`fa' & yngchtru<=`la')
	qui gen eT0 = (e==1&g==0) 
	qui gen eT1 = (e==1&g==1) 
	qui gen eC0 = (e==0&g==0) 
	qui gen eC1 = (e==0&g==1) 
	
	
	
	
	
	 
	 
	//------------------------------------------------ PART 3  ------------------------------------------------------
	// Fill the Table
	//---------------------------------------------------------------------------------------------------------------	
	capture log close
	log using "`logfileout'", replace
	// ---------------------------------------------------		
	// Compute the proportion taking up welfare by Treatment vs Control
	// & the two age groups defined in PART 1. Specifically, use a
	// linear regression with RA and pre-RA variables as covariates.
	// ---------------------------------------------------
	qui reg afdcon eT* eC*   $pscorevars, cluster(id) noc 
	matrix define V = e(V)
	matrix define V = vecdiag(V[1..4,1..4])
	
	matrix define `whatwedo' = J(4,4,.)
	matrix rownames `whatwedo' = "AFDC" "JF" "Diff" "DinD"
	matrix colnames `whatwedo' = "Mean `fa'-`la'" "SE" "Mean `fb'-`lb'"  "SE"
	matrix define `whatwedo'[1,1] = _b[eC1] 
	matrix define `whatwedo'[2,1] = _b[eT1]
	matrix define `whatwedo'[1,2] = sqrt(V[1,4])
	matrix define `whatwedo'[2,2] = sqrt(V[1,2])
	matrix define `whatwedo'[1,3] = _b[eC0]
	matrix define `whatwedo'[2,3] = _b[eT0]
	matrix define `whatwedo'[1,4] = sqrt(V[1,3])
	matrix define `whatwedo'[2,4] = sqrt(V[1,1])

	//----------------------------------------------------
	// Compute figures appearning in the notes to the Table.
	// ---------------------------------------------------
	di ""
	di ""
	di "========================================================= `whatwedo'"
	di "The number of case-months is =" e(N)
	di "The number of cases is =" e(N_clust)
	//----------------------------------------------------
	// Compute the SEs for all the differences in means appearing in the Table.
	// ---------------------------------------------------
	qui lincom eT0-eC0
	matrix define `whatwedo'[3,3] = r(estimate) // JF impact on group with youngest kid who should not be affected by TL
	matrix define `whatwedo'[3,4] = r(se)	    // SE of JF impact
	qui lincom eT1-eC1
	matrix define `whatwedo'[3,1] = r(estimate) // JF impact on group with youngest kid who should not be affected by TL
	matrix define `whatwedo'[3,2] = r(se)		// SE of the JF impact
	qui lincom eT1-eC1-eT0+eC0
	matrix define `whatwedo'[4,1] = r(estimate) // Difference in JF impacts
	matrix define `whatwedo'[4,2] = r(se)		// SE of the DinD
	//------------------------------------------------------
	di ""
	matrix list `whatwedo', noheader format(%6.3f)
	di ""
	di ""
	log close
end



	//------------------------------------------------ PART 4  ------------------------------------------------------
	// Execution
	//---------------------------------------------------------------------------------------------------------------
	AnticipationTest "`jf_dtain'"
	







