//--------------------------------------------------------------------------------------------- GrantInferredSizekidcount
// This code produces the content of Table A1 (Online Appendix),
// that is, in the JF sample it cross tabulated the measured of AU size inferred from the welfare grant amount and kidcount.
// 
// This code is embedded into a program to make the output (written to STATA Results' window) more readable.
//
// This code has five parts:
// 	PART 1: infers AU size from grant amount for JF sample
//  PART 2: use date and infer AU size for JF-sample
//  PART 3: cross tabulate
//  PART 4: execute
// 
// This code take as inputs:
// 	1. pre-generated MDRC data
// 
// This code outputs:
// 	1. A .log file with the table.
// 
// Last Revision: 09/03/2015
//-------------------------------------------------------------------------------------------------------------------------------
args jf_dtain 





capture program drop GrantInferredSizekidcount
capture program define GrantInferredSizekidcount
args jf_dtain 

	
	
	
	
	//------------------------------------------------ PART 1  ------------------------------------------------------
	// Pick what you want to do by setting a few local variables
	//---------------------------------------------------------------------------------------------------------------   
	local fq = 1
	local lq = 7
	local whatwedo 		"TableA1"
	local logfileout	"$oJF/`whatwedo'.log"		// for keeping track
	

	//------------------------------------------------ PART 2  ------------------------------------------------------
	// Use JF sample and bring in Policy Parameters.
	// Infer AU size for JF-sample.
	//---------------------------------------------------------------------------------------------------------------	
	qui use id month year quarter e afdcamt kidcount using "`jf_dtain'" if e==1&quarter>=`fq'&quarter<=`lq', clear
	sort id year quarter month

	//--------------------------------------------
	// AU size based on matching exactly the grant amount (aka MAP), treatment sample only.
	// Clearly, the MAP amount is available only in months when the case is on assistance.
	// The code below thus "spreads" over months when off welfare.
	// It also "spreads" over months when case is on welfare but grant not exactly equal to MAP.
	//
	// NOTES:
	//	a. 	We only consider AU sizes up to 8
	//
	//	b. 	e=0 identifies the control group for which we cannot use the grant amount to infer the AU size
	//      since the grant amount could be reduced due to earnings.
	//
	//	c. 	the unreduced grant amount (aka MAP) varies by whether or not the case received Housing Subsidies (HS)
	//     	AU's size		MAP if HS=0		MAP if HS=1
	//			1			333 [350]			306 [300]
	//			2			443 [450]			407 [400]
	//			3			543 [550]			500 [500]
	//			4			639 [650]			588 [600]
	//			5			731 [750]			672 [700]
	//			6			827 [850]			761 [750]
	//			7			933 [950]			858 [850]
	//			8			1031 [1050]			948 [950]
	// 		Because grant amounts are rounded to nearest $50 in MDRC's Public Use Files (see amounts reported in brakets), 
	// 		we face a situation in which e.g. an observed grant amount of $950 could correspond to a
	// 		AU size = 7 w/o HS or to a AU size = 9 with HS. Below we resolve this indeterminancy by assuming that
	// 		e.g. all of the $950 grants are for a AU size=7 w/o HS.
	//
	//	d. 	We believe that some of the very high sizes inferred from grant amounts are mistakes due
	//  	to overpayment in a few months(recall that we are limiting attention to units that at RA had 
	//  	1 or 2 kids so it is highly improbable that they ballooned to a AU size of 5,6,7, or 8
	//  	during the first 21 months); for this reason we do the following:
	//  	we replace the size of a given month if the size of the month before and/or after are smaller 
	//  	and we do this when the size of the month is one of the suspiciously high values of 5,6,7, or 8.
	//  	The details of this emerge from the code below.
	//--------------------------------------------
	
	
	// -----------------------------------------------------------------------------
	// inferring AU size using rounded grant amount (see explanation in a. through c. above)
	// -----------------------------------------------------------------------------
	qui gen hsizegrant = .
	qui replace hsizegrant = 1 if afdcamt==350|afdcamt==300
	qui replace hsizegrant = 2 if afdcamt==450|afdcamt==400
	qui replace hsizegrant = 3 if afdcamt==550|afdcamt==500
	qui replace hsizegrant = 4 if afdcamt==650|afdcamt==600
	qui replace hsizegrant = 5 if afdcamt==750|afdcamt==700 
	qui replace hsizegrant = 6 if afdcamt==850
	qui replace hsizegrant = 7 if afdcamt==950   
	qui replace hsizegrant = 8 if afdcamt==1050
	qui gen hsizegrant_orig = hsizegrant
	
	// -----------------------------------------------------------------------------
	// Dealing with probable over-payments (see explanation in d. above)
	// Note: this code produces few changes, whether we apply it or not does not affect the results. 
	// -----------------------------------------------------------------------------
	qui gen hsizegrant_lag = .
	qui gen hsizegrant_lead = .
	sort id month
	qui bys id: replace hsizegrant_lag = hsizegrant[_n-1]
	qui bys id: replace hsizegrant_lead = hsizegrant[_n+1]
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead<hsizegrant& hsizegrant==5
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead<hsizegrant& hsizegrant==6
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead<hsizegrant& hsizegrant==7
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead<hsizegrant& hsizegrant==8
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead==.& hsizegrant==5
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead==.& hsizegrant==6
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead==.& hsizegrant==7
	qui replace hsizegrant = hsizegrant_lag if hsizegrant_lag<hsizegrant&hsizegrant_lead==.& hsizegrant==8
	qui replace hsizegrant = hsizegrant_lead if hsizegrant_lag==.&hsizegrant_lead<hsizegrant& hsizegrant==5
	qui replace hsizegrant = hsizegrant_lead if hsizegrant_lag==.&hsizegrant_lead<hsizegrant& hsizegrant==6
	qui replace hsizegrant = hsizegrant_lead if hsizegrant_lag==.&hsizegrant_lead<hsizegrant& hsizegrant==7
	qui replace hsizegrant = hsizegrant_lead if hsizegrant_lag==.&hsizegrant_lead<hsizegrant& hsizegrant==8
	
	
	qui replace hsizegrant = . if hsizegrant_lag==.&hsizegrant_lead==.& hsizegrant==5 
	qui replace hsizegrant = . if hsizegrant_lag==.&hsizegrant_lead==.& hsizegrant==6
	qui replace hsizegrant = . if hsizegrant_lag==.&hsizegrant_lead==.& hsizegrant==7
	qui replace hsizegrant = . if hsizegrant_lag==.&hsizegrant_lead==.& hsizegrant==8
	
	drop *_lag
	drop *_lead		

	// -----------------------------------------------------------------------------
	// After the replacements above, assume that when off AFDC the size is as when on until
	// the next time it is on again at which  point we start using the new size and so on 
	// -----------------------------------------------------------------------------
	sort id month
	qui by id: replace hsizegrant = hsizegrant[_n-1] if hsizegrant==.& hsizegrant[_n-1]~=.	
	// -----------------------------------------------------------------------------
	// Assume that when off AFDC at the start of the preRA period the size is as when on for the first time
	// -----------------------------------------------------------------------------
	foreach n of numlist 1(1)30 {
		sort id month
		qui by id: replace hsizegrant = hsizegrant[_n+1] if hsizegrant[_n]==.& hsizegrant[_n+1]~=.
	}	
	
	
	
	//------------------------------------------------ PART 3  ------------------------------------------------------
	// Cross tabulate the grant-inferred measure of AU size and kidcount
	//---------------------------------------------------------------------------------------------------------------
	capture log close
	log using "`logfileout'", replace
	
	di "Cross tabulation when no back/forward filling:"
	tab hsizegrant_orig kidcount 
	tab hsizegrant_orig kidcount , nofreq col
	di "Cross tabulation after back/forward filling:"
	tab hsizegrant kidcount 
	tab hsizegrant kidcount , nofreq col
	log close
end





//------------------------------------------------ PART 5  ------------------------------------------------------
// Execute
//---------------------------------------------------------------------------------------------------------------
GrantInferredSizekidcount "`jf_dtain'"





